use "data processed\public_eupower2.dta", clear

set more off

*************************************Define variable lists*************************************************************************************
* Control Variables as global
global controls  preelection  election_year  employagri_ln gva_agric_pct gdppercap_eu100 unemploymentrate ///
 sscouncil_pct  eusupport  newmember  
*apply with $controls
global years  y2 y3 y4 y5 y6 y7 y8 y9 y10 y11 y12 y13 y14 y15 y16 y7 y18 y19 y20 y21 y22 y23 y24 y25 y26 y27 y28 y29 y30 y31
*apply with $years
global timetrends lin_timetrend squared_timetrend cubic_timetrend quartic_timetrend
*Country dummies
global Dcountry Dcountry*
*Country year dummies
global coyear Dcoyear*
****
global dep ccap_pct agricfund_pct ln_ccap_pct ctot_pct
*Create differences; here!
 foreach var in $controls{
 clonevar d`var'=`var'
 replace d`var'=d.`var'
 }
 global dcontrols dpreelection  delection_year  demployagri_ln dgva_agric_pct dgdppercap_eu100 dunemploymentrate  dsscouncil_pct  deusupport 

global treated Denmark Netherlands Ireland Luxembourg Latvia Austria
 ***** 
order country_name country_id year ccap_pct natcom   natcom_puredummy natcombud natcomreg $controls 
**********************************************************************************************************************************************
**********************************************************************************************************************************************


reg ccap_pct gva_agric_pct gdppercap_eu100
*****************************Descriptive Statistics*******************************************************************************************
*Table1
format %9.3f agricfund_pct ccap_pct ln_agricfund_pct ln_ccap_pct natcom natcombud natcomreg preelection election_year   ///
employagri_ln  gva_agric_pct size unemploymentrate gdppercap_eu100 newmember sscouncil_pct eusupport natcom_preelect lin_timetrend natcom_puredummy
*anderes Format 
sum ccap_pct natcom agricfund_pct natcombud natcomreg preelection election_year   employagri_ln  size unemploymentrate gdppercap_eu100 ///
newmember sscouncil_pct eusupport natcom_preelect lin_timetrend natcom_puredummy if ccap_pct != .,format

reg ccap_pct natcom $controls id_* $years
matrix input A=(0, 0, 0, 0 ,0 \ 0, 0 ,0,0,0  \ 0, 0 ,0,0,0 \ 0, 0 ,0,0,0 \ 0, 0 ,0,0,0  \ 0, 0 ,0,0,0  \0, 0, 0,0,0 \0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0,0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0 \0, 0, 0,0,0\0, 0, 0,0,0  )

local no=1
foreach var in ccap_pct	agricfund_pct	ctot_pct	natcom	natcom_puredummy	natcombud	natcomreg	network ///
preelection	election_year	employagri_ln	gva_agric_pct	unemploymentrate	gdppercap_eu100	newmember	///
sscouncil_pct	eusupport	Eucouncil	Eupres{
sum `var' if e(sample)
local obs=r(N)

local mean=r(mean)
local sd=r(sd)
local min=r(min)
local max=r(max)

matrix A[`no',1]=`obs'
matrix A[`no',2]=`mean'
matrix A[`no',3]=`sd'
matrix A[`no',4]=`min'
matrix A[`no',5]=`max'

local no=`no'+1
}

matrix rownames A = "\textit{Agricultural Fund Share}"	"Agricultural Fund Share (100)"	"\textit{Overall Funds Share}"	///
"\textit{Commissioner}"	"\textit{Commissioner (Binary)}"	"\textit{Commissioner (B)}"	"\textit{Commissioner (R)}"	"\textit{Time in Office}"	"\textit{Pre-election Year}" ///
	"\textit{Election Year}"	"Employment Agriculture (ln)"	"\textit{GVA Agriculture}"	"\textit{Unemployment Rate}"	"\textit{Per Capita GDP (EU=100)}"	///
	"\textit{New Member State}"	"\textit{Voting Power Council}"	"\textit{Domestic EU Support}"	"\textit{Council Presidency}"	"\textit{EC President}"
//
matrix colnames A=N Mean SD Min Max
mat list A

estout matrix(A, fmt(0 2 2 2 2 ) )using "tables\Pub_Table1.txt",replace   ///
style(tab) delimiter(_tab ) title() 

esttab matrix(A, fmt(0 2 2 2 2 ) )using "tables\Pub_Table1.tex",label replace ///
 title(\textbf{Descriptive Statistics}) ///
 booktabs ///
alignment(D{.}{.}{-1}D{.}{.}{-1}D{.}{.}{-1}D{.}{.}{-1}D{.}{.}{-1}) ///
addnote(\footnotesize{These are the notes.}) ///
 depvars ///
nonumbers ///
 noabbrev  
 

************************************************************************************************************************************************
************************************Table 2 - Main regressions**********************************************************************************
* Control Variables as global
global controls  preelection  election_year  employagri_ln gva_agric_pct gdppercap_eu100 unemploymentrate ///
 sscouncil_pct  eusupport  newmember  

********************************************2.1************************************
estimates drop _all
qui eststo est2_1_ccap_pct:ivreg2 ccap_pct   $controls   ,   cluster(country_name year)
estadd scalar adj_R =e(r2_a) 

*******************************************************************************************
********************************Bootstrap*****2.2********************************************
*********************************************************************************************
quietly{
use "data processed\public_eupower2.dta", clear
*reg ccap_pct natcom $controls $years ttrend* 
ivreg2  ccap_pct natcom $controls   $years  Dcountry*, noc cluster(country_name year)
mat a=e(b)
mat alpha=a[1,1]
mat list alpha
global treat_t = (_b[natcom] - .0)/ _se[natcom]
global treat_coeff =_b[natcom]

*Dependent variables
*global dep  ccap_pct 
global interest natcom
global vars $controls $years  Dcountry*

*Restricted wild bootstrap
 boot ccap_pct   natcom  $vars    ,unit(country_name )  bots($bots)  
 global Pvalue_Rademacher =r(Pvalue_Rad)
  global Pvalue_Webb=r(Pvalue_Webb)
 display "Pvalue_Rademacher=" $Pvalue_Rademacher "  &  Pvalue_Webb="$Pvalue_Webb
 use "data processed\public_eupower2.dta", clear
 
 *Randomization inference
 quietly RITdef ccap_pct   natcom  $vars    ,unit(country_name year)
  *use "data processed\Random.dta",clear  
 RIT natcom, bots($bots)
  scalar list Pvalue_RIbeta
 scalar list  Pvalue_RIT

  use "data processed\public_eupower2.dta", clear
 eststo est2_2_ccap_pct: xtivreg2 ccap_pct natcom $controls $years, fe cluster(country_name year)
 estadd scalar adj_R =e(r2_a) 
 estadd scalar Pvalue_Rademacher=$Pvalue_Rademacher
 estadd scalar Pvalue_Webb=$Pvalue_Webb
 estadd scalar Pvalue_RIbeta=Pvalue_RIbeta
 estadd scalar Pvalue_RIT=Pvalue_RIT
 estadd scalar Pvalue_xtreg =ttail(e(df_m),abs(_b[natcom]/_se[natcom]))
   }

*********************************************************************************************
********************************Bootstrap*****2.3********************************************
*********************************************************************************************
quietly{
use "data processed\public_eupower2.dta", clear

ivreg2  ccap_pct natcom $controls   $years  Dcountry* ttrend* , noc cluster(country_name year)
mat a=e(b)
mat alpha=a[1,1]
mat list alpha
global treat_t = (_b[natcom] - .0)/ _se[natcom]
global treat_coeff =_b[natcom]

*Dependent variables
*global dep  ccap_pct 
global interest natcom
global vars $controls $years  Dcountry* ttrend* 

*Restricted wild bootstrap
 boot ccap_pct   natcom  $vars    ,unit(country_name )  bots($bots)  
 global Pvalue_Rademacher =r(Pvalue_Rad)
  global Pvalue_Webb=r(Pvalue_Webb)
 display "Pvalue_Rademacher=" $Pvalue_Rademacher "  &  Pvalue_Webb="$Pvalue_Webb
 use "data processed\public_eupower2.dta", clear
 
 *Randomization inference
 quietly RITdef ccap_pct   natcom  $vars    ,unit(country_name year)
  *use "data processed\Random.dta",clear  
 RIT natcom, bots($bots)
  scalar list Pvalue_RIbeta
 scalar list  Pvalue_RIT

  use "data processed\public_eupower2.dta", clear
 eststo est2_3_ccap_pct: xtivreg2 ccap_pct natcom $controls $years ttrend* , fe cluster(country_name year)
 estadd scalar adj_R =e(r2_a) 
 estadd scalar Pvalue_Rademacher=$Pvalue_Rademacher
 estadd scalar Pvalue_Webb=$Pvalue_Webb
 estadd scalar Pvalue_RIbeta=Pvalue_RIbeta
 estadd scalar Pvalue_RIT=Pvalue_RIT
  estadd scalar Pvalue_xtreg =ttail(e(df_m),abs(_b[natcom]/_se[natcom]))
  }
  




  *******************************************************************************************
********************************Bootstrap*****2.4********************************************
*********************************************************************************************
quietly{
use "data processed\public_eupower2.dta", clear

ivreg2  ccap_pct natcom $controls  Eucouncil Eupres $years  Dcountry* ttrend* , noc cluster(country_name year)
mat a=e(b)
mat alpha=a[1,1]
mat list alpha
global treat_t = (_b[natcom] - .0)/ _se[natcom]
global treat_coeff =_b[natcom]

*Dependent variables
*global dep  ccap_pct 
global interest natcom
global vars $controls Eucouncil Eupres $years  Dcountry* ttrend* 

*Restricted wild bootstrap
 boot ccap_pct   natcom  $vars    ,unit(country_name )  bots($bots)  
 global Pvalue_Rademacher =r(Pvalue_Rad)
  global Pvalue_Webb=r(Pvalue_Webb)
 display "Pvalue_Rademacher=" $Pvalue_Rademacher "  &  Pvalue_Webb="$Pvalue_Webb
 use "data processed\public_eupower2.dta", clear
 
 *Randomization inference
 quietly RITdef ccap_pct   natcom  $vars    ,unit(country_name year)
  *use "data processed\Random.dta",clear  
 RIT natcom, bots($bots)
  scalar list Pvalue_RIbeta
 scalar list  Pvalue_RIT

  use "data processed\public_eupower2.dta", clear
 eststo est2_4_ccap_pct: xtivreg2 ccap_pct natcom $controls  Eucouncil Eupres $years ttrend* , fe cluster(country_name year)
 estadd scalar adj_R =e(r2_a) 
 estadd scalar Pvalue_Rademacher=$Pvalue_Rademacher
 estadd scalar Pvalue_Webb=$Pvalue_Webb
 estadd scalar Pvalue_RIbeta=Pvalue_RIbeta
 estadd scalar Pvalue_RIT=Pvalue_RIT
  estadd scalar Pvalue_xtreg =ttail(e(df_m),abs(_b[natcom]/_se[natcom]))
  }
  

* ************Control Variables as global, update with the two additional EU variables
global controls  preelection  election_year  employagri_ln  gdppercap_eu100 unemploymentrate ///
 sscouncil_pct  eusupport  newmember  gva_agric_pct Eucouncil Eupres


*******************************************************************************************
********************************Bootstrap******2.5*****************************************
******************************Other dependent variable*************************************
xtset country_id year 
*Overall budget and agricultural Commissioner
quietly{
use "data processed\public_eupower2.dta", clear

*reg ccap_pct natcom $controls $years ttrend* 
qui ivreg2  agricfund_pct natcom $controls   $years ttrend* Dcountry*, noc cluster(country_name year)
mat a=e(b)
mat alpha=a[1,1]
mat list alpha
global treat_t = (_b[natcom] - .0)/ _se[natcom]
global treat_coeff =_b[natcom]

*Dependent variables
*global dep  ccap_pct 
global interest natcom

global vars $controls $years Dcountry* ttrend* 

*Restricted wild bootstrap
 boot    agricfund_pct natcom  $vars    ,unit(country_name )  bots($bots)  
 global Pvalue_Rademacher =r(Pvalue_Rad)
  global Pvalue_Webb=r(Pvalue_Webb)
 display "Pvalue_Rademacher=" $Pvalue_Rademacher "  &  Pvalue_Webb="$Pvalue_Webb
 use "data processed\public_eupower2.dta", clear
 
 *Randomization inference
 quietly RITdef agricfund_pct   natcom  $vars    ,unit(country_name year)
  *use "data processed\Random.dta",clear  
 RIT natcom, bots($bots)
  scalar list Pvalue_RIbeta
 scalar list  Pvalue_RIT

  use "data processed\public_eupower2.dta", clear
 eststo est2_5_agricfund_pct:xtivreg2 agricfund_pct natcom $controls $years ttrend* , fe cluster(country_name year)
 estadd scalar adj_R =e(r2_a) 
 estadd scalar Pvalue_Rademacher=$Pvalue_Rademacher
 estadd scalar Pvalue_Webb=$Pvalue_Webb
 estadd scalar Pvalue_RIbeta=Pvalue_RIbeta
 estadd scalar Pvalue_RIT=Pvalue_RIT
 estadd scalar Pvalue_xtreg =ttail(e(df_m),abs(_b[natcom]/_se[natcom]))
  }
  
 
******************************************************************************************
********************************Bootstrap******2.6****************************************
******************************Other dependent variable************************************
xtset country_id year 
*Overall budget and agricultural Commissioner
quietly{
use "data processed\public_eupower2.dta", clear


qui ivreg2  agricfund_pct natcom $controls   $years ttrend* Dcountry*, noc cluster(country_name year)
qui ivreg2  ctot_pct natcom $controls   $years ttrend* Dcountry* if e(sample), noc cluster(country_name year)
mat a=e(b)
mat alpha=a[1,1]
mat list alpha
global treat_t = (_b[natcom] - .0)/ _se[natcom]
global treat_coeff =_b[natcom]

*Dependent variables
*global dep  ccap_pct 
global interest natcom

global vars $controls $years ttrend* Dcountry*

*Dependent variables
*global dep  ccap_pct 
global interest natcom

global vars $controls $years ttrend* Dcountry*

*Restricted wild bootstrap
 boot ctot_pct   natcom  $vars    ,unit(country_name )  bots($bots)  
 global Pvalue_Rademacher =r(Pvalue_Rad)
  global Pvalue_Webb=r(Pvalue_Webb)
 display "Pvalue_Rademacher=" $Pvalue_Rademacher "  &  Pvalue_Webb="$Pvalue_Webb
 use "data processed\public_eupower2.dta", clear
 
 *Randomization inference
 quietly RITdef ctot_pct    natcom  $vars    ,unit(country_name year)
  *use "data processed\Random.dta",clear  
 RIT natcom, bots($bots)
  scalar list Pvalue_RIbeta
 scalar list  Pvalue_RIT

  use "data processed\public_eupower2.dta", clear
  qui ivreg2  ccap_pct natcom $controls   $years ttrend* Dcountry*, noc cluster(country_name year)
 eststo est2_6_ctot_pct:xtivreg2 ctot_pct natcom $controls $years ttrend* if e(sample), fe cluster(country_name year)
 estadd scalar adj_R =e(r2_a) 
 estadd scalar Pvalue_Rademacher=$Pvalue_Rademacher
 estadd scalar Pvalue_Webb=$Pvalue_Webb
 estadd scalar Pvalue_RIbeta=Pvalue_RIbeta
 estadd scalar Pvalue_RIT=Pvalue_RIT
 estadd scalar Pvalue_xtreg =ttail(e(df_m),abs(_b[natcom]/_se[natcom]))
  }
 
*Table 2
 estout est2_1_ccap_pct est2_2_ccap_pct  est2_3_ccap_pct est2_4_ccap_pct   est2_5_agricfund_pct  est2_6_ctot_pct ///
 using "tables\Pub_Table2.txt", ///
replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("-") label(Coef.)) ///
se(fmt(3) par([ ]) vacant("-") label(SE))) style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats( adj_R N Pvalue_xtreg Pvalue_Rademacher Pvalue_Webb  Pvalue_RIbeta Pvalue_RIT, ///
labels( "Adj. R-Squared" "Number of Observations" "xtreg p-value" "WCRB p-value (2-point)" "WCRB p-value (6-point)" "RI p-value ($\beta$)" "RI p-value (t)") fmt( 2 0 3 3 3 3 3 3)) drop( o.* id* $years  ttrend* _cons, relax)  ///
order(natcom )  indicate( y*   ttrend*  , labels(yes no) )


****************************************************Figures: Figure 2*********************************
 use "data processed\public_eupower2.dta", clear
 reg ccap_pct natcom $controls $years ttrend* 
qui ivreg2  ccap_pct natcom $controls   $years ttrend* Dcountry*, noc cluster(country_name year)
mat a=e(b)
mat alpha=a[1,1]
mat list alpha
global treat_t = (_b[natcom] - .0)/ _se[natcom]
global treat_coeff =_b[natcom]
global interest natcom
global vars $controls $years ttrend* Dcountry*
* Comment in if using Stata 13 or 12. The program needs to save this file in the old version.
 *Randomization inference, please comment in if you want to generate a new dta. file for the figures. This will take some additiona time.
quietly RITdef ccap_pct   natcom  $vars    ,unit(country_name year)
  *use "data processed\Random.dta",clear  
 RIT natcom, bots($botF)
  scalar list Pvalue_RIbeta
 scalar list  Pvalue_RIT
********************************Figures of treatment vs. placebo distribution***************************
use RIT_file.dta,clear
save "RIT_figures.dta",replace
cap noisily saveold "RIT_figures.dta",replace version(12)

********************************************************************************************************
use "RIT_figures.dta",clear
gen treat_t=$treat_t
gen beta = $treat_coeff

gen Abs_tstar=abs(tstar)
gen Abs_betastar=abs(betastar)

histogram tstar, width(0.2) frequency xline($treat_t, lwidth(thick) lcolor(cranberry)) scheme(s2mono) ///
legend(off) graphregion(color(white)) ytitle(F) yline(0, lwidth( medsmall )) xtitle(Simulated placebo t-values) 
graph save  "graphics\Simul_t", replace
graph export "graphics\Simul_t.png",width(4000) replace 

histogram betastar, bin(35) frequency xline($treat_coeff, lwidth(thick) lcolor(cranberry)) scheme(s2mono) ///
legend(off) graphregion(color(white)) ytitle(Empirical probability density function) yline(0, lwidth( medsmall )) ///
xtitle(Simulated placebo coefficients) xscale(range( -0.4 0.8)) ///
ytitle("Frequency", margin(medium)  )
graph save  "graphics\Simul_b", replace
graph export "graphics\Simul_b.png",width(4000) replace 
*T Cum
cap noisily drop count count_cum
sort tstar
gen count=[_n]
gen count_cum=count/100
twoway (scatter count_cum tstar ,  msize(vsmall) ), xline($treat_t, lwidth(thick) lcolor(cranberry)) scheme(s2mono) ///
graphregion(color(white)) xtitle(Simulated t-values) ytitle(Empirical cumulative distribution function)
graph save  "graphics\Simul_t_cdf", replace
graph export "graphics\Simul_t_cdf.png",width(4000) replace 
*Beta Cum
cap noisily drop count count_cum
sort betastar
gen count=[_n]
gen count_cum=count/100
twoway (scatter count_cum betastar ,  msize(vsmall) ), xline($treat_coeff, lwidth(thick) lcolor(cranberry)) ///
graphregion(color(white)) scheme(s2mono) xtitle(Simulated placebo coefficients) ytitle(Empirical cumulative distribution function) xscale(range( -0.4 0.7)) 
graph save  "graphics\Simul_b_cdf", replace
graph export "graphics\Simul_b_cdf.png",width(4000) replace 

***Two sided
cap noisily drop count count_cum
sort Abs_tstar
gen count=[_n]
gen count_cum=count/100
twoway (scatter count_cum Abs_tstar ,  msize(vsmall) ), xline($treat_t, lwidth(thick) lcolor(cranberry)) scheme(s2mono) ///
graphregion(color(white)) xtitle(Simulated t-values) ytitle(Empirical cumulative distribution function)
graph save  "graphics\Simul_t_cdf_abs", replace
graph export "graphics\Simul_t_cdf_abs.png",width(4000) replace 
*Beta Cum absolute values
cap noisily drop count count_cum
sort Abs_betastar
gen count=[_n]
gen count_cum=count/100
twoway (scatter count_cum Abs_betastar ,  msize(vsmall) ), xline($treat_coeff, lwidth(thick) lcolor(cranberry)) ///
graphregion(color(white)) scheme(s2mono) xtitle(Simulated placebo coefficients (absolute values), margin(medium)) ytitle(Empirical cumulative distribution function) xscale(range( -0. 0.7)) 
graph save  "graphics\Simul_b_cdf_abs", replace
graph export "graphics\Simul_b_cdf_abs.png",width(4000) replace 

use "data processed\public_eupower2.dta", clear

   

   
   
   
   
*********************************************************************************************************************************
******************************Table 3: Lags and Leads****************************************************************************
*********************************************************************************************************************************
* ************Control Variables as global, update with the two additional EU variables
global controls  preelection  election_year  employagri_ln  gdppercap_eu100 unemploymentrate ///
 sscouncil_pct  eusupport  newmember  gva_agric_pct Eucouncil Eupres
 
 use "data processed\public_eupower2.dta", clear
**********************************************************************************************************************************
****************************************************Table3: Lags and Leads***************************************************************
**********************************************************************************************************************************


xtset country_id year 
global vars $controls F2natcom F1natcom  $years ttrend* Dcountry*
ivreg2  ccap_pct natcom `vars' , noc cluster(country_name year)
mat a=e(b)
mat alpha=a[1,1]
mat list alpha
global treat_t = (_b[natcom] - .0)/ _se[natcom]
global treat_coeff =_b[natcom]
 estimates drop _all 
*Restricted wild bootstrap
 boot ccap_pct   natcom  $vars    ,unit(country_name )  bots($bots)  
 global Pvalue_Rademacher =r(Pvalue_Rad)
  global Pvalue_Webb=r(Pvalue_Webb)
 display "Pvalue_Rademacher=" $Pvalue_Rademacher "  &  Pvalue_Webb="$Pvalue_Webb
    use "data processed\public_eupower2.dta", clear
  *Randomization inference
 quietly RITdef ccap_pct   natcom  $vars    ,unit(country_name year)
  *use "data processed\Random.dta",clear  
 RIT natcom, bots($bots)
  scalar list Pvalue_RIbeta
 scalar list  Pvalue_RIT
 
 use "data processed\public_eupower2.dta", clear
 qui ivreg2  ccap_pct F2natcom F1natcom  natcom  $controls $years ttrend* Dcountry*, noc cluster(country_name year)
eststo est5_1: xtivreg2 ccap_pct F2natcom F1natcom  natcom  $controls $years ttrend* if e(sample), fe cluster(country_name year)
 estadd scalar adj_R =e(r2_a) 
 estadd scalar Pvalue_Rademacher=$Pvalue_Rademacher
 estadd scalar Pvalue_Webb=$Pvalue_Webb
 estadd scalar Pvalue_RIbeta=Pvalue_RIbeta
 estadd scalar Pvalue_RIT=Pvalue_RIT
 estadd scalar Pvalue_xtreg =ttail(e(df_m),abs(_b[natcom]/_se[natcom]))
 ****************************************************************************************************************
 *************Lags
 use "data processed\public_eupower2.dta", clear
xtset country_id year 
global vars $controls L1natcom  L2natcom    L3natcom   L4natcom   $years ttrend* Dcountry* 
qui ivreg2  ccap_pct  natcom L1natcom  L2natcom    L3natcom   L4natcom  $controls $years ttrend* Dcountry*, noc cluster(country_name year)
mat a=e(b)
mat alpha=a[1,1]
mat list alpha
global treat_t = (_b[natcom] - .0)/ _se[natcom]
global treat_coeff =_b[natcom]
 
*Restricted wild bootstrap
 boot ccap_pct   natcom  $vars    ,unit(country_name )  bots($bots)  
 global Pvalue_Rademacher =r(Pvalue_Rad)
  global Pvalue_Webb=r(Pvalue_Webb)
 display "Pvalue_Rademacher=" $Pvalue_Rademacher "  &  Pvalue_Webb="$Pvalue_Webb
 
 use "data processed\public_eupower2.dta", clear
   *Randomization inference
 quietly RITdef ccap_pct   natcom  $vars    ,unit(country_name year)
  *use "data processed\Random.dta",clear  
 RIT natcom, bots($bots)
  scalar list Pvalue_RIbeta
 scalar list  Pvalue_RIT
   use "data processed\public_eupower2.dta", clear
  qui ivreg2  ccap_pct  natcom L1natcom  L2natcom    L3natcom   L4natcom  $controls $years ttrend* Dcountry*, noc cluster(country_name year)
 eststo est5_7: xtivreg2 ccap_pct   natcom L1natcom  L2natcom    L3natcom   L4natcom  $controls $years ttrend* if e(sample), fe cluster(country_name year)
 estadd scalar adj_R =e(r2_a) 
 estadd scalar Pvalue_Rademacher=$Pvalue_Rademacher
 estadd scalar Pvalue_Webb=$Pvalue_Webb
 estadd scalar Pvalue_RIbeta=Pvalue_RIbeta
 estadd scalar Pvalue_RIT=Pvalue_RIT
 estadd scalar Pvalue_xtreg =ttail(e(df_m),abs(_b[natcom]/_se[natcom]))
 
  *************Lags and Leads
use "data processed\public_eupower2.dta", clear
xtset country_id year 
global vars $controls F1natcom F2natcom L1natcom  L2natcom    L3natcom   L4natcom   $years ttrend* Dcountry*
qui ivreg2  ccap_pct  natcom F1natcom F2natcom L1natcom  L2natcom    L3natcom   L4natcom  $controls $years ttrend* Dcountry*, noc cluster(country_name year)
mat alpha=a[1,1]
mat list alpha
global treat_t = (_b[natcom] - .0)/ _se[natcom]
global treat_coeff =_b[natcom]

*Restricted wild bootstrap
 boot ccap_pct   natcom  $vars    ,unit(country_name )  bots($bots)  
 global Pvalue_Rademacher =r(Pvalue_Rad)
  global Pvalue_Webb=r(Pvalue_Webb)
 display "Pvalue_Rademacher=" $Pvalue_Rademacher "  &  Pvalue_Webb="$Pvalue_Webb
 use "data processed\public_eupower2.dta", clear
  *Randomization inference
 quietly RITdef ccap_pct   natcom  $vars    ,unit(country_name year)
  *use "data processed\Random.dta",clear  
 RIT natcom, bots($bots)
  scalar list Pvalue_RIbeta
 scalar list  Pvalue_RIT
   use "data processed\public_eupower2.dta", clear
  qui ivreg2  ccap_pct  natcom F1natcom F2natcom L1natcom  L2natcom    L3natcom   L4natcom  $controls $years ttrend* Dcountry*, noc cluster(country_name year)
 eststo est5_8: xtivreg2 ccap_pct  F1natcom F2natcom natcom L1natcom  L2natcom    L3natcom   L4natcom  $controls $years ttrend* if e(sample), fe cluster(country_name year)
 estadd scalar adj_R =e(r2_a) 
 estadd scalar Pvalue_Rademacher=$Pvalue_Rademacher
 estadd scalar Pvalue_Webb=$Pvalue_Webb
 estadd scalar Pvalue_RIbeta=Pvalue_RIbeta
 estadd scalar Pvalue_RIT=Pvalue_RIT
 estadd scalar Pvalue_xtreg =ttail(e(df_m),abs(_b[natcom]/_se[natcom]))

estout est5_1 est5_7 est5_8 using "tables\Pub_Table3.txt", replace title("-") ///
noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(SE))) ///
style(tab) delimiter(_tab ) stats( adj_R N Pvalue_xtreg Pvalue_Rademacher Pvalue_Webb  Pvalue_RIbeta Pvalue_RIT, ///
labels( "Adj. R-Squared" "Number of Observations" "xtreg p-value" "WCRB p-value (2-point)" "WCRB p-value (6-point)" "RI p-value ($\beta$)" "RI p-value (t)") fmt( 2 0 3 3 3 3 3 3)) drop($controls id* o.* $years ttrend* _cons, relax) order(F2natcom F1natcom natcom L1natcom L2natcom L3natcom L4natcom) ///
 indicate($controls   y*  ttrend*  , labels(yes no) )

 
 
 
 
regsave natcom F1natcom F2natcom L1natcom  L2natcom    L3natcom   L4natcom , ci
gen ll_natcom = 0
replace ll_natcom = -2 if var == "F2natcom"
replace ll_natcom = -1 if var == "F1natcom"
replace ll_natcom = 0 if var == "natcom"
replace ll_natcom = 1 if var == "L1natcom"
replace ll_natcom = 2 if var == "L2natcom"
replace ll_natcom = 3 if var == "L3natcom"
replace ll_natcom = 4 if var == "L4natcom"

local sd2line "(line ci_upper ci_lower ll_natcom, sort lpattern(dash dash) msym(d))"
label define cat -2 "t-2" -1 "t-1" 0 "t" 1 "t+1" 2 "t+2" 3 "t+3" 4 "t+4" 
label values ll_natcom cat
sort  ll_natcom

twoway   (line ci_lower ll_natcom, lwidth(vthin) color(gs14)   ytick(-1 (1) 1, gstyle(major)) graphregion(color(white)) ) ///
(line ci_upper ll_natcom, lwidth(vthin)  color(gs14) ) (rcap ci_upper ci_lower ll_natcom, lwidth(medium) msize(vlarge) color(black)) ///
(line coef ll_natcom, lwidth(medthin) lpattern(dash) color(black))  (scatter coef ll_natcom,  msymbol( square  ) msize(medlarge) color(cranberry))  , ///
 yline(0, lwidth( medsmall ) lcolor(black) )  yline(-1  1  2, lwidth( vvvthin ) lcolor(gs5)) legend(off) ///
  yscale(range(-1.1 2.3))  ylabel(-1 0 1 2, ticks tlwidth(vthin ) nogrid) ytitle (Coefficient of Commissioner) ///
xlabel(-2(1)4, valuelabel) xmtick(-2(1)4) xtitle("") yscale(lwidth(medium)) xscale(lwidth(medium))

graph save "graphics\leads and lags2ccap_pct", replace
 graph export "graphics\leads and lags2ccap_pct.png",width(4000) replace

 
 
 
*************Leads and lags (individually)
use "data processed\public_eupower2.dta", clear
  
*(as for Table6)
xtset country_id year
estimates drop _all 
* F2natcom F1natcom  natcom L1natcom L2natcom L3natcom 

eststo estA5_1: xtivreg2 ccap_pct F2natcom  natcom   $controls  $years ttrend*, fe cluster(country_name year)
estadd scalar Joint=r(p)
estadd scalar adj_R =e(r2_a)

eststo estA5_2: xtivreg2 ccap_pct F1natcom natcom   $controls  $years ttrend*, fe cluster(country_name year)
 estadd scalar Joint=r(p)
 estadd scalar adj_R =e(r2_a)
 
eststo estA5_3: xtivreg2 ccap_pct 		natcom  $controls $years ttrend*, fe cluster(country_name year)
 estadd scalar Joint=r(p)
 estadd scalar adj_R =e(r2_a)
  
 eststo estA5_4:  xtivreg2 ccap_pct 	natcom L1natcom  $controls $years ttrend*, fe cluster(country_name year)
  estadd scalar Joint=r(p)
  estadd scalar adj_R =e(r2_a)
   
eststo estA5_5:  xtivreg2 ccap_pct   	natcom  L2natcom     $controls  $years ttrend*, fe cluster(country_name year)
 estadd scalar Joint=r(p)
 estadd scalar adj_R =e(r2_a)
 
eststo estA5_6:  xtivreg2 ccap_pct 		natcom     L3natcom   $controls  $years ttrend*, fe cluster(country_name year)
  estadd scalar Joint=r(p)
  estadd scalar adj_R =e(r2_a)
 	
 eststo estA5_7:  xtivreg2 ccap_pct 	natcom   L4natcom   $controls  $years ttrend*, fe cluster(country_name year)
 estadd scalar Joint=r(p)
estadd scalar adj_R =e(r2_a)

estout estA5_1 estA5_2 estA5_3 estA5_4 estA5_5 estA5_6 estA5_7 using "tables\Pub_TableA6.txt", replace title("-") ///
noabbrev wrap label cells(b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(SE))) ///
style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) stats( adj_R Joint N , labels( "Adj. R-Squared" "Joint" "Number of Observations" ) ///
 fmt( 2 2 0)) drop($controls id* o.* $years ttrend* _cons, relax) order(F2natcom F1natcom natcom L1natcom L2natcom L3natcom L4natcom) ///

 

********************Appendix Table, Individual lag or lead********************************************************
quietly{
estimates drop _all  
eststo estA6_1: xtivreg2 ccap_pct F2natcom   $controls  $years ttrend*, fe cluster(country_name year)
	estadd scalar adj_R =e(r2_a)

 eststo estA6_2: xtivreg2 ccap_pct F1natcom   $controls  $years ttrend*, fe cluster(country_name year)
	estadd scalar adj_R =e(r2_a)
 
 eststo estA6_3: xtivreg2 ccap_pct natcom   $controls  $years ttrend*, fe cluster(country_name year)
	estadd scalar adj_R =e(r2_a)
  
 eststo estA6_4:  xtivreg2 ccap_pct L1natcom  $controls $years ttrend*, fe cluster(country_name year)
	estadd scalar adj_R =e(r2_a)
    
 eststo estA6_5:  xtivreg2 ccap_pct  L2natcom  $controls $years ttrend*, fe cluster(country_name year)
	estadd scalar adj_R =e(r2_a)
 
 eststo estA6_6:  xtivreg2 ccap_pct  L3natcom   $controls  $years ttrend*, fe cluster(country_name year)
	estadd scalar adj_R =e(r2_a)
 	
 eststo estA6_7:  xtivreg2 ccap_pct L4natcom   $controls  $years ttrend*, fe cluster(country_name year)
	estadd scalar adj_R =e(r2_a)
}
estout estA6_1 estA6_2  estA6_3 estA6_4 estA6_5 estA6_6 estA6_7 using "tables\Pub_TableA7.txt", replace title("-") ///
noabbrev wrap label cells(b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(SE))) ///
style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) stats( adj_R  N , labels( "Adj. R-Squared" "Joint" "Number of Observations" ) ///
fmt( 2 2 0)) drop($controls id* o.* $years ttrend* _cons, relax) order(F2natcom F1natcom natcom L1natcom L2natcom L3natcom L4natcom) ///

 
 
****************************************************************************************************************************
*********************Robustness to leaving out individual treated  countries************************************************
****************************************************************************************************************************
xtset country_id year 

*TABLE 4
*Estimations without every country (xtreg)
estimates drop _all
local clist 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 25 26 27 
foreach var of local clist{
eststo est4_`var': xtivreg2 ccap_pct natcom $controls $years ttrend* if country_id!=`var', fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)
estadd local Countryeffect="Yes"
}

eststo big: xtivreg2 ccap_pct natcom $controls $years ttrend* if country_name != "Germany" & country_name !="France" & country_name !="Italy" & country_name !="United Kingdom" & country_name !="Spain" , fe cluster(country_name year) 
estadd scalar adj_R =e(r2_a)

estout est4_* big using "tables\Pub_TableA8.txt", replace title("-")  ///
mlabels("Belgium" "Denmark" "Germany" "Greece" "Spain" "France" "Ireland" ///
Italy "Luxembourg" "Netherlands" ///
 "Austria" "Portugal"  "Finland"  "Sweden"  "United Kingdom" ///
 "Cyprus"   "Malta"   "Czech Republic"   "Poland"   "Slovenia"  ///
 "Slovakia" "Hungary" "Estonia" "Latvia" "Lithunia" "Large Countries") ///
noabbrev wrap label cells(b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(SE))) ///
style(tab) delimiter(_tab )starlevels(^{*} 0.10 ^{**} 0.05 ^{***} 0.01) stats(N , labels( "Number of Observations" ) fmt(  0)) ///
drop($controls id* o.* $years ttrend* _cons, relax) 

 


estout est4_2 est4_7 est4_9 est4_10 est4_11 est4_26 big using "tables\Pub_Table4.1.txt", replace title("-") ///
noabbrev wrap label cells(b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(SE))) ///
mlabel( "Denmark" "Ireland" "Luxembourg" "Netherlands" "Austria" "Latvia" "Big countries") unstack ///
style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) stats(Countryeffect N , labels( "Country Fixed effects" "Number of Observations" ) fmt(  0)) ///
drop($controls id* o.* $years ttrend* _cons, relax)   indicate( y*   ttrend* , labels(yes no) )
 

 ****************************************************************************************************************************
 *Selection on observables Altonji and Oster , compare Nunn and Wantchekon (2011)
****************************************************************************************************************************

matrix input A=(0,0,0,0 \ 0,0,0,0 \ 0,0,0 ,0\ 0,0,0,0)
*************country + year dummies vs. all wo ttrend
 local no=1
 xtreg ccap_pct natcom  $years, fe //No restrictions2
scalar B1_l=_b[natcom]
 xtreg ccap_pct natcom  $years $controls, fe  //
scalar B1_f=_b[natcom]
scalar ratio=B1_f/(B1_l-B1_f)
matrix A[`no',3]=abs(B1_f/(B1_l-B1_f))
matrix A[`no',1]=abs(B1_l)
matrix A[`no',2]=abs(B1_f)
*Oster
 *Only one control
 reg ccap_pct natcom  	 Dcountry* $years 
 scalar Rmin=e(r2)
 scalar Betamin=_b[natcom]
reg ccap_pct natcom   Dcountry*  $controls $years 	 
*est store V`var'
scalar RMAX=min(1,2.2*e(r2))
scalar Rtilda=e(r2)
scalar Betatilda=_b[natcom]
scalar delta=1
scalar BetaIden1=Betatilda-delta*(Betamin-Betatilda)*(RMAX-Rtilda)/(Rtilda-Rmin)
reg ccap_pct natcom   Dcountry*  $controls $years ttrend*	 Dcountry*
est store V
estadd scalar BetaIden1
matrix A[`no',4]=abs(BetaIden1)
*************country + year dummies vs. all with ttrend

local no=2
 xtreg ccap_pct natcom $years , fe    //No restrictions2
scalar B1_l=_b[natcom]
 xtreg ccap_pct natcom   $years $controls  ttrend*, fe //
scalar B1_f=_b[natcom]
scalar ratio=B1_f/(B1_l-B1_f)
matrix A[`no',3]=abs(B1_f/(B1_l-B1_f))
matrix A[`no',1]=abs(B1_l)
matrix A[`no',2]=abs(B1_f)
*Oster
reg ccap_pct natcom  	 Dcountry* $years 
 scalar Rmin=e(r2)
 scalar Betamin=_b[natcom]
reg ccap_pct natcom   Dcountry*  $controls $years ttrend*	 
scalar RMAX=min(1,2.2*e(r2))
scalar Rtilda=e(r2)
scalar Betatilda=_b[natcom]
scalar delta=1
scalar BetaIden1=Betatilda-delta*(Betamin-Betatilda)*(RMAX-Rtilda)/(Rtilda-Rmin)
reg ccap_pct natcom   Dcountry*  $controls $years ttrend*	 Dcountry*
est store V2
estadd scalar BetaIden1
matrix A[`no',4]=abs(BetaIden1)

**********country dummies vs. all wo ttrend
local no=3
 xtreg ccap_pct natcom, fe  //No restrictions
scalar B1_l=_b[natcom]
 xtreg ccap_pct natcom  $controls $years, fe //
scalar B1_f=_b[natcom]
scalar ratio=B1_f/(B1_l-B1_f)
matrix A[`no',3]=abs(B1_f/(B1_l-B1_f))
matrix A[`no',1]=abs(B1_l)
matrix A[`no',2]=abs(B1_f)
*Oster
 reg ccap_pct natcom  Dcountry*	 
 scalar Rmin=e(r2)
 scalar Betamin=_b[natcom]
reg ccap_pct natcom   Dcountry*  $controls $years 	
scalar RMAX=min(1,2.2*e(r2))
scalar Rtilda=e(r2)
scalar Betatilda=_b[natcom]
scalar delta=1
scalar BetaIden1=Betatilda-delta*(Betamin-Betatilda)*(RMAX-Rtilda)/(Rtilda-Rmin)
reg ccap_pct natcom   Dcountry*  $controls $years ttrend*	 Dcountry*
est store V3
estadd scalar BetaIden1
matrix A[`no',4]=abs(BetaIden1)
**********country dummies vs. all with ttrend
local no=4
xtreg ccap_pct natcom, fe  //No restrictions
scalar B1_l=_b[natcom]
xtreg ccap_pct natcom  $years $controls  ttrend*, fe //
scalar B1_f=_b[natcom]
scalar ratio=B1_f/(B1_l-B1_f)
matrix A[`no',3]=abs(B1_f/(B1_l-B1_f))
matrix A[`no',1]=abs(B1_l)
matrix A[`no',2]=abs(B1_f)
*Oster
 reg ccap_pct natcom  Dcountry*	 
 scalar Rmin=e(r2)
 scalar Betamin=_b[natcom]
reg ccap_pct natcom   Dcountry*  $controls $years ttrend*	
scalar RMAX=min(1,2.2*e(r2))
scalar Rtilda=e(r2)
scalar Betatilda=_b[natcom]
scalar delta=1
scalar BetaIden1=Betatilda-delta*(Betamin-Betatilda)*(RMAX-Rtilda)/(Rtilda-Rmin)
reg ccap_pct natcom   Dcountry*  $controls $years ttrend*	 Dcountry*
est store V4
estadd scalar BetaIden1
matrix A[`no',4]=abs(BetaIden1)

mat list A
 /*
matrix rownames A =  "1"  "2" "3"  "4" 
estout matrix(A, fmt(%9.2f ) )using "tables\Pub_TableA7_ccap_pct.txt",replace    collabels(b1u b1r ratio) ///
style(tab) delimiter(_tab ) title()  ///
labcol2("(natcom id_*  years) vs (natcom id_* years controls)" "(natcom id_*  years) vs (natcom  id_* years controls  ttrend*) " "(natcom id_*) vs (natcom  id_* controls years)" "(natcom id_*) vs (natcom id_* years controls  ttrend*) " "Oster Beta")

esttab matrix(A, fmt(%9.2f ) )using "tables\Pub_TableA7_ccap_pct.tex",replace    collabels(b1u b1r ratio) ///
style(tab) delimiter(_tab ) title()  ///
labcol2("(natcom id_*  years) vs (natcom id_* years controls)" "(natcom id_*  years) vs (natcom  id_* years controls  ttrend*) " "(natcom id_*) vs (natcom  id_* controls years)" "(natcom id_*) vs (natcom id_* years controls  ttrend*) " "Oster Beta")
*/

matrix B = A[1..2,1..4]
mat list B
matrix rownames B =  "1"  "2" 

estout matrix(B, fmt(%9.2f ) )using "tables\Pub_Table4.2.txt",replace    collabels(b1u b1r ratio) ///
style(tab) delimiter(_tab ) title()  ///
labcol2("(natcom id_*  years) vs (natcom id_* years controls)" "(natcom id_*  years) vs (natcom  id_* years controls  ttrend*) " "Oster Beta")
 


***************************************************************************************************************
**************************************EBA style simulation*****************************************************
*********This robustness tests randomly omits individual countries and control variables, *********************
********and returns the p-values and Beta coefficients*********************************************************

*This makes sure that Users of Stata 13 or 12 can use the file. if you possess Stata 14 you can comment this in.
/*
global controlsX  preelection  election_year  employagri_ln  gdppercap_eu100 unemploymentrate ///
 sscouncil_pct  eusupport  newmember  gva_agric_pct Eucouncil Eupres ttrend*
 set seed 12345 
use "data processed\public_eupower2.dta", clear
simulate  pvalue=r(pval) Beta  = r(b) SE= r(se) ///
 , reps(10000) saving(eba_country_file, replace): eba_country   ,obs(27) controls(12) //Acess the program defined below

 
 *Based on 10.000 observations
use "eba_country_file.dta",clear
save "eba_country_file.dta",replace 
cap noisily saveold "eba_country_file.dta", version(12)  replace
*/
use "eba_country_file.dta",clear
histogram pvalue, width(0.005) percent   xtick(0(0.01)0.11) xscale(range(0 0.05)) ///
ytitle(Percent of simulated repetitions) scheme(s2mono)  legend(off) graphregion(color(white))  xtitle(p-value)
graph save  "graphics\EBA_p", replace
graph export "graphics\EBA_p.png",width(4000) replace 

histogram Beta, width(0.04) percent  xtick(0.3(0.1)1.2) xscale(range(0.2 1.2)) scheme(s2mono) legend(off) graphregion(color(white))  xtitle(Treatment Effects)
graph save  "graphics\EBA_beta", replace
graph export "graphics\EBA_beta.png",width(4000) replace 





*****************************************************************************************************************
**********************************************************************************************************************************
**********************************************************Table A5***************************************************************
**********************************************************************************************************************************
 use "data processed\public_eupower2.dta", clear
 xtset country_id year 
 label  var network "Time in Office"
gen natcom_puredummy_network=natcom_puredummy*network

* reference model
eststo est3_1: xtivreg2 ccap_pct natcom $controls $years ttrend*, fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)

* with natocm_puredummy instead of natcom 
eststo est3_2: xtivreg2 ccap_pct natcom_puredummy $controls $years ttrend* , fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)

* interaction Network Agric  
eststo est3_3: xtivreg2 ccap_pct natcom_puredummy natcom_puredummy_network  $controls ttrend* $years, fe cluster(country_name year)
*xtivreg2 ccap_pct natcom_puredummy natcom_puredummyXnetwork  $controls ttrend* $years, fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)

  estout est3_1 est3_2 est3_3 using "tables\Pub_TableA5.txt", ///
  varlabels(natcom_puredummy_network "Commissioner (Binary) X Time in Office") ///
  replace title("-") noabbrev wrap label cells(b(star fmt(%9.3f) vacant("-") ///
  label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(SE))) style(tab) delimiter(_tab ) ///
  starlevels(* 0.10 ** 0.05 *** 0.01) stats( adj_R N Pvalue_xtreg Pvalue_Rademacher Pvalue_Webb  Pvalue_RIbeta Pvalue_RIT, ///
labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3 3 3 3 3)) ///
  drop($controls id* o.* $years ttrend* _cons, relax)  indicate($controls ttrend*  , labels(yes no)   )
 

****************************Figures*****************************************************************************************
xtivreg2 ccap_pct natcom_puredummy natcom_puredummy_network   $controls ttrend* $years, fe cluster(country_name year)

 cap drop marginal semarginal conf1 conf2
predictnl marginal = _b[natcom_puredummy]+_b[natcom_puredummy_network]*network if e(sample) &network<=4, se(semarginal)
gen conf1 = marginal-2.58*semarginal if e(sample) &network<=4
gen conf2 = marginal+2.58*semarginal if e(sample) &network<=4
 line marginal conf1 conf2 network if e(sample) &network<=4, ///
lpattern(solid dashed dashed) lwidth(thick vthin vthin) lcolor(black gs14 gs14) ///
sort  ytitle("Marginal Effect of Commissioner")    name(Network,replace) ///
 graphregion(color(white))  yline(0, lwidth( medsmall ) lcolor(black) )  yline(-.5  0.5  1, lwidth( vvvthin ) lcolor(gs5)) legend(off) ///
  yscale(range(-.55 1.2))  ylabel(-.5  0 .5  1, ticks tlwidth(vthin ) nogrid)  yscale(lwidth(medium)) ///
  xscale(lwidth(medium)) xtitle("Time in Office", margin( small ))  pstyle(p2 p1 p1)
    graph save  "graphics\NatcomNetworkccap_pct99", replace
 graph export "graphics\NatcomNetworkccap_pct99.png",width(4000) replace 
  
 cap drop marginal semarginal conf1 conf2
predictnl marginal = _b[natcom_puredummy]+_b[natcom_puredummy_network]*network if e(sample) &network<=4, se(semarginal)
gen conf1 = marginal-1.96*semarginal if e(sample) &network<=4
gen conf2 = marginal+1.96*semarginal if e(sample) &network<=4
 line marginal conf1 conf2 network if e(sample) &network<=4, ///
lpattern(solid dashed dashed) lwidth(thick vthin vthin) lcolor(black gs14 gs14) ///
sort  ytitle("Marginal effect of Commissioner")    name(Network,replace) ///
 graphregion(color(white))  yline(0, lwidth( medsmall ) lcolor(black) )  yline(-.5  0.5  1, lwidth( vvvthin ) lcolor(gs5)) legend(off) ///
  yscale(range(-.55 1.2))  ylabel(-.5  0 .5  1, ticks tlwidth(vthin ) nogrid)  yscale(lwidth(medium)) ///
  xscale(lwidth(medium)) xtitle("Time in Office", margin( small ))  pstyle(p2 p1 p1)
    graph save  "graphics\NatcomNetworkccap_pct95", replace
 graph export "graphics\NatcomNetworkccap_pct95.png",width(4000) replace 
 

use "data processed\public_eupower2.dta", clear
*************************************************************************************************************
****************************Table A9: Large table with an array of robustness tests**************************
*************************************************************************************************************

*To be added ln_ccap_pct ln_agricfund_pct  
 quietly {
 ********Robustness
  xtivreg2 ccap_pct natcom $controls d.($controls) ttrend*  $years , fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)
est store v1
estadd local delta_control="One lag"

*squared country specific ttrend
 xtivreg2 ccap_pct natcom $controls $years ttrend* t2trend* , fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)
estadd local delta_control="No"
est store v3

*squared  and cubic country specific ttrend
 xtivreg2 ccap_pct natcom $controls $years ttrend* t2trend* t3trend* , fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)
estadd local delta_control="No"
est store v4

*squared  and cubic and quartic country specific ttrend
 xtivreg2 ccap_pct natcom $controls $years ttrend* t2trend* t3trend* t4trend*, fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)
estadd local delta_control="No"
est store v5

*Changes in controls and *squared  and cubic and quartic country specific ttrend
xtivreg2 ccap_pct natcom $controls d.($controls)  $years ttrend* t2trend* t3trend* t4trend*, fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)
estadd local delta_control="One lag"
est store v6


xtivreg2 ln_ccap_pct natcom $controls  ttrend*  $years , fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)
estadd local delta_control="No"
est store v7

xtivreg2 ln_ccap_pct natcom $controls ttrend*  t2trend*  t4trend2-t4trend15 t3trend2-t4trend15 y3-y25, fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)
estadd local delta_control="No"
est store v8

xtivreg2 ln_ccap_pct natcom $controls d.($controls) ttrend*  t2trend2-t2trend15 t4trend2-t4trend15 t3trend2-t4trend15 y3-y25 , fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)
estadd local delta_control="One lag"
est store v9

 *Budget Commissioner
xtivreg2 ctot_pct natcombud $controls  $years ttrend*, fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)
estadd local delta_control="No"
est store v10

*xtregional Commissioner
 xtivreg2 ccsp_pct natcomreg $controls $years ttrend*, fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)
estadd local delta_control="No"
est store v11
}
	
estout v1  v3 v4 v5 v6    using "tables\Pub_TableA9.txt", ///
replace title("-") noabbrev wrap label ///
cells(b(nostar fmt(%9.3f) vacant("-") label(Coef.)) ///
se(fmt(3) par([ ]) vacant("-") label(SE)) p(fmt(3) par( ) vacant("-") label(p-value))) ///
style(tab) delimiter(_tab ) ///
stats(delta_control adj_R N , labels( "ChangeControls" "Adj. R-Squared" "Number of Observations" ) fmt( 2 2 0)) drop( o.* id* $years  ttrend* size D.size _cons, relax)  ///
order(natcom   )  indicate( y*   ttrend* t2trend* t3trend* t4trend*, labels(yes no) ) ///
keep(natcom ) mlabel("ccap_pct"  "ccap_pct"  "ccap_pct"  "ccap_pct" "ccap_pct"    )

estout v10 v11 v7 v8 v9   using "tables\Pub_TableA9.txt", ///
append title(\textbf{Regression Results}) noabbrev wrap label ///
cells(b(nostar fmt(%9.3f) vacant("-") label(Coef.)) ///
se(fmt(3) par([ ]) vacant("-") label(SE)) p(fmt(3) par( ) vacant("-") label(p-value))) ///
style(tab) delimiter(_tab ) ///
stats(delta_control adj_R N , labels( "ChangeControls" "Adj. R-Squared" "Number of Observations" ) fmt( 2 2 0)) drop( o.* id* $years  ttrend* size D.size _cons, relax)  ///
order(natcom   )  indicate( y*   ttrend* t2trend* t3trend* t4trend*, labels(yes no) ) ///
keep(natcom natcombud natcomreg) mlabel(  "ctot_pct and budget"  "ccsp_pct and Regional" "ln_ccap_pct" "ln_ccap_pct" "ln_ccap_pct"  )
	

 
**********************************************************************************************************
**********************************************************************************************************
 
 *Placebo Checks
 *xtregional Commissioner
eststo estPlacebo1: xtivreg2 ccap_pct natcomreg $controls $years ttrend*, fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)
 *xtregional Commissioner
eststo estPlacebo2: xtivreg2 ccap_pct natcombud $controls $years ttrend*, fe cluster(country_name year)
estadd scalar adj_R =e(r2_a)

 estout estPlacebo1 estPlacebo2 using "tables\Pub_Table A10.txt", ///
replace title("-") noabbrev wrap label cells(b(star fmt(%9.3f) vacant("-") label(Coef.)) ///
se(fmt(3) par([ ]) vacant("-") label(SE))) style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats( adj_R N delta_control, labels( "Adj. R-Squared" "Number of Observations" ("Controls")) fmt( 2 0 3 3)) drop( o.* id* $years  ttrend* _cons, relax)  ///
keep(natcomreg natcombud) ///
order(natcomreg natcombud  )  indicate( y*  , labels(yes no) )
 
**********************************************************************************************************
************************************Figures***************************************************************
**********************************************************************************************************

 xtset country_id year 
  label var year "Year"
 label var ccap_pct "Agricultural Fund Share"
 *foreach dep in $dep{
 *Predictions 
reg ccap_pct natcom $controls $years ttrend* id*		
predict ccap_pct_P
replace ccap_pct_P = ccap_pct_P-_b[natcom]*natcom
gen diff_ccap_pct = ccap_pct-ccap_pct_P

global treated Denmark Netherlands Ireland Luxembourg Latvia Austria

foreach treated in $treated{

twoway (scatter ccap_pct_P ccap_pct year) /// 
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) if country_name =="`treated'" 
graph save "graphics\VSccap_pct(`treated')", replace
graph export "graphics\VSccap_pct(`treated').png",width(4000) replace

}

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
if country_name =="Denmark" & year<=1990 & year >1978, ///
xline(1985 1979) yline (1 2 3 4 5)
gr_edit  .plotregion1._xylines[7].style.editstyle linestyle(color(gs9)) editcopy
// line[7] (y) color
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// plot4 edits
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
graph save "graphics\VSccap_pct(Denmark1)A", replace
graph export "graphics\VSccap_pct(Denmark1)A.png",width(4000) replace

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="Denmark" & year >2000, ///
xline(2004) yline (.9 1 1.1 1.2 1.3)
gr_edit  .plotregion1._xylines[3].style.editstyle linestyle(color(gs9)) editcopy
// line[7] (y) color
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// plot4 edits
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
graph save "graphics\VSccap_pct(Denmark2)A", replace
graph export "graphics\VSccap_pct(Denmark2)A.png",width(4000) replace

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
if country_name =="Netherlands" & year<=1994 & year >1978, ///
xline(1985 1989) yline(2 4 6 8 10)
gr_edit  .plotregion1._xylines[7].style.editstyle linestyle(color(gs9)) editcopy
// line[7] (y) color
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// plot4 edits
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
graph save "graphics\VSccap_pct(Netherlands)A", replace
graph export "graphics\VSccap_pct(Netherlands)A.png",width(4000) replace

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
if country_name =="Ireland" & year<=2000 & year >1983, ///
xline(1989 1993) yline(1.5 2 2.5 3 3.5 4)
gr_edit  .plotregion1._xylines[4].style.editstyle linestyle(color(gs9)) editcopy
// line[4] (y) color
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// plot4 edits
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
graph save "graphics\VSccap_pct(Ireland)A", replace
graph export "graphics\VSccap_pct(Ireland)A.png",width(4000) replace

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="Latvia" & year<=2007 & year >2002, ///
xline(2004 2005) yline(0 .1 .2) xlabel(2004 2005 2006)
gr_edit  .plotregion1._xylines[3].style.editstyle linestyle(color(gs9)) editcopy
// line[7] (y) color
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// plot4 edits
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
graph save "graphics\VSccap_pct(Latvia)A", replace
graph export "graphics\VSccap_pct(Latvia)A.png",width(4000) replace


twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="Luxembourg" & year<=1998 & year >1987, ///
xline(1993 1995) yline ( 0)
gr_edit  .plotregion1._xylines[3].style.editstyle linestyle(color(gs9)) editcopy
// line[7] (y) color
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// plot4 edits
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
graph save "graphics\VSccap_pct(Luxembourg)A", replace
graph export "graphics\VSccap_pct(Luxembourg)A.png",width(4000) replace

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="Austria" & year<=2007 & year >1993, ///
xline(1995 2004) yline (0 .5 1 1.5)
gr_edit  .plotregion1._xylines[5].style.editstyle linestyle(color(gs9)) editcopy
// line[7] (y) color
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// plot4 edits
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
graph save "graphics\VSccap_pct(Austria)A", replace
graph export "graphics\VSccap_pct(Austria)A.png",width(4000) replace

graph combine ///
"graphics\VSccap_pct(Austria)A" ///
"graphics\VSccap_pct(Denmark1)A" ///
"graphics\VSccap_pct(Denmark2)A" ///
"graphics\VSccap_pct(Ireland)A" ///
"graphics\VSccap_pct(Latvia)A" ///
"graphics\VSccap_pct(Luxembourg)A" ///
"graphics\VSccap_pct(Netherlands)A" ///

gr_edit .Edit , cmd(.set_cols = 4) cmd(.set_rows = 0) 
// Graph edits
gr_edit .plotregion1.graph1.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph2.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph3.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph4.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph7.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph6.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph5.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
// Graph color
gr_edit .style.editstyle declared_ysize(2.7) editcopy
// Graph size
gr_edit .plotregion1.AddMarker added_markers editor 160.9553278581973 25.20412397341198
gr_edit .plotregion1.added_markers_new = 1
gr_edit .plotregion1.added_markers_rec = 1
gr_edit .plotregion1.added_markers[1].style.editstyle  marker( symbol(circle_hollow) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(large) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) line( width(thin) color(black) pattern(solid)) area( linestyle( width(thin) color(ltbluishgray) pattern(solid)) shadestyle( color(ltbluishgray) intensity(inten100) fill(pattern10))) label( textstyle( horizontal(center) vertical(middle) angle(default) size(small) color(black) position() margin(zero) linestyle( width(thin) color(black) pattern(solid))) position(6) textgap(half_tiny) horizontal(default) vertical(default)) dots( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(vtiny) angle(horizontal) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(medium) backangle(horizontal)) connect(direct) connect_missings(yes) editcopy
// edits
gr_edit .plotregion1.AddMarker added_markers editor 160.9553278581973 19.47285243420159
gr_edit .plotregion1.added_markers_new = 2
gr_edit .plotregion1.added_markers_rec = 2
gr_edit .plotregion1.added_markers[2].style.editstyle  marker( symbol(circle_hollow) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(large) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) line( width(thin) color(black) pattern(solid)) area( linestyle( width(thin) color(ltbluishgray) pattern(solid)) shadestyle( color(ltbluishgray) intensity(inten100) fill(pattern10))) label( textstyle( horizontal(center) vertical(middle) angle(default) size(small) color(black) position() margin(zero) linestyle( width(thin) color(black) pattern(solid))) position(6) textgap(half_tiny) horizontal(default) vertical(default)) dots( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(vtiny) angle(horizontal) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(medium) backangle(horizontal)) connect(direct) connect_missings(yes) editcopy
// edits
gr_edit .plotregion1.AddTextBox added_text editor 21.83436451926938 150.5106545608963
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
// markers[1] edits
gr_edit .plotregion1.added_markers[1].style.editstyle marker(symbol(circle)) editcopy
// markers[1] symbol
gr_edit .plotregion1.added_markers[2].style.editstyle marker(symbol(circle)) editcopy
gr_edit .plotregion1.added_markers[2].style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit .plotregion1.added_markers[2].style.editstyle marker(linestyle(color(gs6))) editcopy
// markers[2] edits
gr_edit .plotregion1.added_markers[1].style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit .plotregion1.added_markers[1].style.editstyle marker(linestyle(color(cranberry))) editcopy
// markers[1] edits
gr_edit .plotregion1.AddTextBox added_text editor 25.10756042533891 162.5099670394112
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit plotregion1.added_text[2].text = {}
gr_edit plotregion1.added_text[2].text.Arrpush EAGGF Share (in percent)
// editor text[2] edits
gr_edit plotregion1.AddTextBox added_text editor 19.30756042533891 162.5099670394112
gr_edit plotregion1.added_text_new = 3
gr_edit plotregion1.added_text_rec = 3
gr_edit plotregion1.added_text[3].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit plotregion1.added_text[3].text = {}
gr_edit plotregion1.added_text[3].text.Arrpush Predicted EAGGF Share (in percent)
// editor text[3] edits

graph save "graphics\VSccap_pct_AllCombinedA_Treated", replace
graph export "graphics\VSccap_pct_AllCombinedA_Treated.png",width(5000) replace


*Untreated countries
twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="Italy" & year<=2006 & year >1978, ///
 xline (1985 1989 1993 1995 2004)
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.Edit, style(cols(1)) style(rows(0)) keepstyles
// legend edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
// label[2] edits
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[3].DragBy .3224016342538855 0
// label[3] reposition
gr_edit .legend.plotregion1.label[3].DragBy -.3224016342538836 0
// label[3] reposition
gr_edit .legend.plotregion1.DragBy 2.095610622650245 1.450807354142482
// key region reposition
gr_edit .legend.plotregion1.DragBy -1.450807354142478 .6448032685077829
// key region reposition
gr_edit .legend.plotregion1.DragBy .1612008171269438 .6448032685077361
// key region reposition
graph save "graphics\VSccap_pct(Italy)A", replace
graph export "graphics\VSccap_pct(Italy)A.png",width(4000) replace

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="Greece" & year<=2006 & year >=1981, ///
 xline ( 1985 1989 1993 1995 2004)
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.Edit, style(cols(1)) style(rows(0)) keepstyles
// legend edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
// label[2] edits
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[3].DragBy .3224016342538855 0
// label[3] reposition
gr_edit .legend.plotregion1.label[3].DragBy -.3224016342538836 0
// label[3] reposition
gr_edit .legend.plotregion1.DragBy 2.095610622650245 1.450807354142482
// key region reposition
gr_edit .legend.plotregion1.DragBy -1.450807354142478 .6448032685077829
// key region reposition
gr_edit .legend.plotregion1.DragBy .1612008171269438 .6448032685077361
// key region reposition
graph save "graphics\VSccap_pct(Greece)A", replace
graph export "graphics\VSccap_pct(Greece)A.png",width(4000) replace


twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="Finland" & year<=2006 & year >1994, ///
 xline ( 1995 2004)
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.Edit, style(cols(1)) style(rows(0)) keepstyles
// legend edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
// label[2] edits
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[3].DragBy .3224016342538855 0
// label[3] reposition
gr_edit .legend.plotregion1.label[3].DragBy -.3224016342538836 0
// label[3] reposition
gr_edit .legend.plotregion1.DragBy 2.095610622650245 1.450807354142482
// key region reposition
gr_edit .legend.plotregion1.DragBy -1.450807354142478 .6448032685077829
// key region reposition
gr_edit .legend.plotregion1.DragBy .1612008171269438 .6448032685077361
// key region reposition
graph save "graphics\VSccap_pct(Finland)A", replace
graph export "graphics\VSccap_pct(Finland)A.png",width(4000) replace

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="United Kingdom" & year<=2006 & year >1978, ///
 xline ( 1985 1989 1993 1995 2004)
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.Edit, style(cols(1)) style(rows(0)) keepstyles
// legend edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
// label[2] edits
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[3].DragBy .3224016342538855 0
// label[3] reposition
gr_edit .legend.plotregion1.label[3].DragBy -.3224016342538836 0
// label[3] reposition
gr_edit .legend.plotregion1.DragBy 2.095610622650245 1.450807354142482
// key region reposition
gr_edit .legend.plotregion1.DragBy -1.450807354142478 .6448032685077829
// key region reposition
gr_edit .legend.plotregion1.DragBy .1612008171269438 .6448032685077361
// key region reposition
graph save "graphics\VSccap_pct(United Kingdom)A", replace
graph export "graphics\VSccap_pct(United Kingdom)A.png",width(4000) replace

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="Germany" & year<=2006 & year >1978, ///
xline (1985 1989 1993 1995 2004)
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.Edit, style(cols(1)) style(rows(0)) keepstyles
// legend edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
// label[2] edits
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[3].DragBy .3224016342538855 0
// label[3] reposition
gr_edit .legend.plotregion1.label[3].DragBy -.3224016342538836 0
// label[3] reposition
gr_edit .legend.plotregion1.DragBy 2.095610622650245 1.450807354142482
// key region reposition
gr_edit .legend.plotregion1.DragBy -1.450807354142478 .6448032685077829
// key region reposition
gr_edit .legend.plotregion1.DragBy .1612008171269438 .6448032685077361
// key region reposition
graph save "graphics\VSccap_pct(Germany)A", replace
graph export "graphics\VSccap_pct(Germany)A.png",width(4000) replace

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="Spain" & year<=2006 & year >1985, ///
 xline (1985 1989 1993 1995 2004)
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region repositiongr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.Edit, style(cols(1)) style(rows(0)) keepstyles
// legend edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
// label[2] edits
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[3].DragBy .3224016342538855 0
// label[3] reposition
gr_edit .legend.plotregion1.label[3].DragBy -.3224016342538836 0
// label[3] reposition
gr_edit .legend.plotregion1.DragBy 2.095610622650245 1.450807354142482
// key region reposition
gr_edit .legend.plotregion1.DragBy -1.450807354142478 .6448032685077829
// key region reposition
gr_edit .legend.plotregion1.DragBy .1612008171269438 .6448032685077361
// key region reposition
graph save "graphics\VSccap_pct(Spain)A", replace
graph export "graphics\VSccap_pct(Spain)A.png",width(4000) replace

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="Belgium" & year<=2006 & year >1978, ///
 xline ( 1985 1989 1993 1995 2004)
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.Edit, style(cols(1)) style(rows(0)) keepstyles
// legend edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
// label[2] edits
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[3].DragBy .3224016342538855 0
// label[3] reposition
gr_edit .legend.plotregion1.label[3].DragBy -.3224016342538836 0
// label[3] reposition
gr_edit .legend.plotregion1.DragBy 2.095610622650245 1.450807354142482
// key region reposition
gr_edit .legend.plotregion1.DragBy -1.450807354142478 .6448032685077829
// key region reposition
gr_edit .legend.plotregion1.DragBy .1612008171269438 .6448032685077361
// key region reposition
// key region repositiongraph save "graphics\VSccap_pct(Belgium)A", replace
graph save "graphics\VSccap_pct(Belgium)A", replace
graph export "graphics\VSccap_pct(Belgium)A.png",width(4000) replace


twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="Portugal" & year<=2006 & year >1985, ///
 xline ( 1989 1993 1995 2004)
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.Edit, style(cols(1)) style(rows(0)) keepstyles
// legend edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
// label[2] edits
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[3].DragBy .3224016342538855 0
// label[3] reposition
gr_edit .legend.plotregion1.label[3].DragBy -.3224016342538836 0
// label[3] reposition
gr_edit .legend.plotregion1.DragBy 2.095610622650245 1.450807354142482
// key region reposition
gr_edit .legend.plotregion1.DragBy -1.450807354142478 .6448032685077829
// key region reposition
gr_edit .legend.plotregion1.DragBy .1612008171269438 .6448032685077361
// key region reposition
graph save "graphics\VSccap_pct(Portugal)A", replace
graph export "graphics\VSccap_pct(Portugal)A.png",width(4000) replace

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="Sweden" & year<=2006 & year >1994, ///
 xline (1979 1985 1989 1993 1995 2004)
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.Edit, style(cols(1)) style(rows(0)) keepstyles
// legend edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
// label[2] edits
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[3].DragBy .3224016342538855 0
// label[3] reposition
gr_edit .legend.plotregion1.label[3].DragBy -.3224016342538836 0
// label[3] reposition
gr_edit .legend.plotregion1.DragBy 2.095610622650245 1.450807354142482
// key region reposition
gr_edit .legend.plotregion1.DragBy -1.450807354142478 .6448032685077829
// key region reposition
gr_edit .legend.plotregion1.DragBy .1612008171269438 .6448032685077361
// key region reposition
graph save "graphics\VSccap_pct(Sweden)A", replace
graph export "graphics\VSccap_pct(Sweden)A.png",width(4000) replace

twoway ///
(line ccap_pct_P  year, lwidth(medthin) lpattern(dash) color(black))	///
(line ccap_pct year, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter ccap_pct_P ccap_pct year) ///
 if country_name =="France" & year<=2006 & year >1978, ///
 xline (1985 1989 1993 1995 2004)
gr_edit  .plotregion1._xylines[1].style.editstyle linestyle(color(gs13)) editcopy
// line[1] (x) color
gr_edit  .plotregion1.plot3.style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit  .plotregion1.plot3.style.editstyle marker(linestyle(color(gs6))) editcopy
// plot3 edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit  .plotregion1.plot4.style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit  .plotregion1.plot4.style.editstyle marker(linestyle(color(cranberry))) editcopy
// Graph color
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[1].fill_if_undrawn.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[2].fill_if_undrawn.setstyle, style(no)
// label[2] edits
// key[2] edits
gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits
// view edits
// key[1] edits
gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits
// view edits
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Predicted EAGGF Share (Percent)
// label[3] edits
gr_edit .legend.plotregion1.label[4].text = {}
gr_edit .legend.plotregion1.label[4].text.Arrpush `"EAGGF Share (Percent)"'
// label[4] edits
gr_edit .legend.plotregion1.DragBy 1.128405719888591 1.289606537015519
// key region reposition
gr_edit .legend.Edit, style(cols(1)) style(rows(0)) keepstyles
// legend edits
gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
// label[2] edits
gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
// label[1] edits
gr_edit .legend.plotregion1.label[3].DragBy .3224016342538855 0
// label[3] reposition
gr_edit .legend.plotregion1.label[3].DragBy -.3224016342538836 0
// label[3] reposition
gr_edit .legend.plotregion1.DragBy 2.095610622650245 1.450807354142482
// key region reposition
gr_edit .legend.plotregion1.DragBy -1.450807354142478 .6448032685077829
// key region reposition
gr_edit .legend.plotregion1.DragBy .1612008171269438 .6448032685077361
// key region reposition
graph save "graphics\VSccap_pct(France)A", replace
graph export "graphics\VSccap_pct(France)A.png",width(4000) replace

graph combine ///
"graphics\VSccap_pct(Belgium)A" ///
"graphics\VSccap_pct(France)A" ///
"graphics\VSccap_pct(Finland)A" ///
"graphics\VSccap_pct(Germany)A" ///
"graphics\VSccap_pct(Greece)A" ///
"graphics\VSccap_pct(Italy)A" ///
"graphics\VSccap_pct(Portugal)A" ///
"graphics\VSccap_pct(Spain)A" ///
"graphics\VSccap_pct(Sweden)A" ///
"graphics\VSccap_pct(United Kingdom)A" 

gr_edit .plotregion1.graph1.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph2.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph3.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph4.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph8.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph7.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph6.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph5.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph9.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .plotregion1.graph10.legend.draw_view.setstyle, style(no)
// legend edits
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
// Graph color
gr_edit .style.editstyle declared_ysize(2.5) editcopy
// Graph size
gr_edit .plotregion1.AddMarker added_markers editor 127.9553278581973 22.20412397341198
gr_edit .plotregion1.added_markers_new = 1
gr_edit .plotregion1.added_markers_rec = 1
gr_edit .plotregion1.added_markers[1].style.editstyle  marker( symbol(circle_hollow) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(large) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) line( width(thin) color(black) pattern(solid)) area( linestyle( width(thin) color(ltbluishgray) pattern(solid)) shadestyle( color(ltbluishgray) intensity(inten100) fill(pattern10))) label( textstyle( horizontal(center) vertical(middle) angle(default) size(small) color(black) position() margin(zero) linestyle( width(thin) color(black) pattern(solid))) position(6) textgap(half_tiny) horizontal(default) vertical(default)) dots( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(vtiny) angle(horizontal) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(medium) backangle(horizontal)) connect(direct) connect_missings(yes) editcopy
// edits
gr_edit .plotregion1.AddMarker added_markers editor 127.9553278581973 16.47285243420159
gr_edit .plotregion1.added_markers_new = 2
gr_edit .plotregion1.added_markers_rec = 2
gr_edit .plotregion1.added_markers[2].style.editstyle  marker( symbol(circle_hollow) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(large) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) line( width(thin) color(black) pattern(solid)) area( linestyle( width(thin) color(ltbluishgray) pattern(solid)) shadestyle( color(ltbluishgray) intensity(inten100) fill(pattern10))) label( textstyle( horizontal(center) vertical(middle) angle(default) size(small) color(black) position() margin(zero) linestyle( width(thin) color(black) pattern(solid))) position(6) textgap(half_tiny) horizontal(default) vertical(default)) dots( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(vtiny) angle(horizontal) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(medium) backangle(horizontal)) connect(direct) connect_missings(yes) editcopy
// edits
gr_edit .plotregion1.AddTextBox added_text editor 21.83436451926938 150.5106545608963
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
// markers[1] edits
gr_edit .plotregion1.added_markers[1].style.editstyle marker(symbol(circle)) editcopy
// markers[1] symbol
gr_edit .plotregion1.added_markers[2].style.editstyle marker(symbol(circle)) editcopy
gr_edit .plotregion1.added_markers[2].style.editstyle marker(fillcolor(gs6)) editcopy
gr_edit .plotregion1.added_markers[2].style.editstyle marker(linestyle(color(gs6))) editcopy
// markers[2] edits
gr_edit .plotregion1.added_markers[1].style.editstyle marker(fillcolor(cranberry)) editcopy
gr_edit .plotregion1.added_markers[1].style.editstyle marker(linestyle(color(cranberry))) editcopy
// markers[1] edits
gr_edit .plotregion1.AddTextBox added_text editor 22.10756042533891 130.5099670394112
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit plotregion1.added_text[2].text = {}
gr_edit plotregion1.added_text[2].text.Arrpush EAGGF Share (in percent)
// editor text[2] edits
gr_edit plotregion1.AddTextBox added_text editor 16.30756042533891 130.5099670394112
gr_edit plotregion1.added_text_new = 3
gr_edit plotregion1.added_text_rec = 3
gr_edit plotregion1.added_text[3].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit plotregion1.added_text[3].text = {}
gr_edit plotregion1.added_text[3].text.Arrpush Predicted EAGGF Share (in percent)
// editor text[3] edits

graph save "graphics\VSccap_pct_AllCombinedA", replace
graph export "graphics\VSccap_pct_AllCombinedA.png",width(5000) replace


sort year eventtime
list year country_name eventtime diff_ccap_pct if eventtime !=.


scatter diff_ccap_pct eventtime if country_name=="Denmark" & year <=1998 & eventtime !=. & eventtime <= 15 , color(gs1)  msymbol(diamond)  || ///
scatter diff_ccap_pct eventtime if country_name=="Denmark" & year >=1999 & eventtime !=. & eventtime <= 15 , color(gs14)  msymbol(diamond) || ///
scatter diff_ccap_pct eventtime if country_name=="Netherlands"  & eventtime !=. & eventtime <= 15 , color(gs6)  msymbol(square) || ///
scatter diff_ccap_pct eventtime if country_name=="Latvia"  & eventtime !=. & eventtime <= 15  , color(gs12) msymbol(square) || ///
scatter diff_ccap_pct eventtime if country_name=="Luxembourg" & eventtime !=. & eventtime <= 15  , color(gs10) || ///
scatter diff_ccap_pct eventtime if country_name=="Austria"  & eventtime !=. & eventtime <= 15 , color(gs4)   || ///
scatter diff_ccap_pct eventtime if country_name=="Ireland"  & eventtime !=. & eventtime <= 15 , color(gs8) msymbol(diamond)  || ///
lowess diff_ccap_pct eventtime if country_name=="Denmark" & year <=1998 & eventtime !=. & eventtime <= 15, bwidth(.5) mean lcolor(gs1) || ///
lowess diff_ccap_pct eventtime if country_name=="Denmark" & year >=1999 & eventtime !=. & eventtime <= 15, bwidth(.4) mean lcolor(gs14)  || ///
lowess diff_ccap_pct eventtime if country_name=="Netherlands"  & eventtime !=. & eventtime <= 15, bwidth(.4) mean lcolor(gs6)  || ///
lowess diff_ccap_pct eventtime if country_name=="Latvia"  & eventtime !=. & eventtime <= 15, bwidth(.3) mean lcolor(gs12) || ///
lowess diff_ccap_pct eventtime if country_name=="Luxembourg"  & eventtime !=. & eventtime <= 15, bwidth(.4) mean lcolor(gs10)|| ///
lowess diff_ccap_pct eventtime if country_name=="Austria"  & eventtime !=. & eventtime <= 15, bwidth(.5) mean  lcolor(gs4) || ///
lowess diff_ccap_pct eventtime if country_name=="Ireland"  & eventtime !=. & eventtime <= 15, bwidth(.7) mean lcolor(gs8) ///
, xline(0, lcolor(black)) yline(0, lcolor(black)) legend(off)

gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .plotregion1.plot10.style.editstyle line(width(medthick)) editcopy
// plot10 width
gr_edit .plotregion1.plot13.style.editstyle line(width(medthick)) editcopy
// plot13 width
gr_edit .plotregion1.plot8.style.editstyle line(width(medthick)) editcopy
// plot8 width
gr_edit .plotregion1.plot14.style.editstyle line(width(medthick)) editcopy
// plot14 width
gr_edit .plotregion1.plot12.style.editstyle line(width(medthick)) editcopy
// plot12 width
gr_edit .plotregion1.plot9.style.editstyle line(width(medthick)) editcopy
// plot9 width
gr_edit .plotregion1.plot11.style.editstyle line(width(medthick)) editcopy
// plot11 width

graph export "graphics\event_ccap_pct(smooth).png",width(4000) replace


sort year eventtime
list year country_name eventtime diff_ccap_pct if eventtime !=.


scatter diff_ccap_pct eventtime if country_name=="Denmark" & year <=1998 & eventtime !=. & eventtime <= 15 , color(gs16)  || ///
scatter diff_ccap_pct eventtime if country_name=="Denmark" & year >=1999 & eventtime !=. & eventtime <= 15 , color(gs16)  || ///
scatter diff_ccap_pct eventtime if country_name=="Netherlands"  & eventtime !=. & eventtime <= 15 , color(gs16)  || ///
scatter diff_ccap_pct eventtime if country_name=="Latvia"  & eventtime !=. & eventtime <= 15  , color(gs16) || ///
scatter diff_ccap_pct eventtime if country_name=="Luxembourg" & eventtime !=. & eventtime <= 15  , color(gs16) || ///
scatter diff_ccap_pct eventtime if country_name=="Austria"  & eventtime !=. & eventtime <= 15 , color(gs16)   || ///
scatter diff_ccap_pct eventtime if country_name=="Ireland"  & eventtime !=. & eventtime <= 15 , color(gs16)  || ///
lowess diff_ccap_pct eventtime if country_name=="Denmark" & year <=1998 & eventtime !=. & eventtime <= 15, bwidth(.5) mean lcolor(gs1) || ///
lowess diff_ccap_pct eventtime if country_name=="Denmark" & year >=1999 & eventtime !=. & eventtime <= 15, bwidth(.4) mean lcolor(gs14)  || ///
lowess diff_ccap_pct eventtime if country_name=="Netherlands"  & eventtime !=. & eventtime <= 15, bwidth(.4) mean lcolor(gs6)  || ///
lowess diff_ccap_pct eventtime if country_name=="Latvia"  & eventtime !=. & eventtime <= 15, bwidth(.3) mean lcolor(gs12) || ///
lowess diff_ccap_pct eventtime if country_name=="Luxembourg"  & eventtime !=. & eventtime <= 15, bwidth(.4) mean lcolor(gs10)|| ///
lowess diff_ccap_pct eventtime if country_name=="Austria"  & eventtime !=. & eventtime <= 15, bwidth(.5) mean  lcolor(gs4) || ///
lowess diff_ccap_pct eventtime if country_name=="Ireland"  & eventtime !=. & eventtime <= 15, bwidth(.7) mean lcolor(gs8) ///
, xline(0, lcolor(black)) yline(0, lcolor(black)) legend(off)

gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .plotregion1.plot10.style.editstyle line(width(medthick)) editcopy
// plot10 width
gr_edit .plotregion1.plot13.style.editstyle line(width(medthick)) editcopy
// plot13 width
gr_edit .plotregion1.plot8.style.editstyle line(width(medthick)) editcopy
// plot8 width
gr_edit .plotregion1.plot14.style.editstyle line(width(medthick)) editcopy
// plot14 width
gr_edit .plotregion1.plot12.style.editstyle line(width(medthick)) editcopy
// plot12 width
gr_edit .plotregion1.plot9.style.editstyle line(width(medthick)) editcopy
// plot9 width
gr_edit .plotregion1.plot11.style.editstyle line(width(medthick)) editcopy
// plot11 width

graph export "graphics\event_ccap_pct(smooth)WorkVersion.png",width(4000) replace


sort year eventtime
list year country_name eventtime diff_ccap_pct if eventtime !=.

scatter diff_ccap_pct eventtime if country_name=="Denmark" & year <=1998 & eventtime !=. & eventtime <= 15 , color(gs16)  || ///
scatter diff_ccap_pct eventtime if country_name=="Denmark" & year >=1999 & eventtime !=. & eventtime <= 15 , color(gs16)  || ///
scatter diff_ccap_pct eventtime if country_name=="Netherlands"  & eventtime !=. & eventtime <= 15 , color(gs16)  || ///
scatter diff_ccap_pct eventtime if country_name=="Latvia"  & eventtime !=. & eventtime <= 15  , color(gs16) || ///
scatter diff_ccap_pct eventtime if country_name=="Luxembourg" & eventtime !=. & eventtime <= 15  , color(gs16) || ///
scatter diff_ccap_pct eventtime if country_name=="Austria"  & eventtime !=. & eventtime <= 15 , color(gs16)   || ///
scatter diff_ccap_pct eventtime if country_name=="Ireland"  & eventtime !=. & eventtime <= 15 , color(gs16)  || ///
lowess diff_ccap_pct eventtime if country_name=="Denmark" & year <=1998 & eventtime !=. & eventtime <= 15, bwidth(.5) mean lcolor(gs1) || ///
lowess diff_ccap_pct eventtime if country_name=="Denmark" & year >=1999 & eventtime !=. & eventtime <= 15, bwidth(.4) mean lcolor(gs14)      || ///
lowess diff_ccap_pct eventtime if country_name=="Netherlands"  & eventtime !=. & eventtime <= 15, bwidth(.4) mean lcolor(gs6)  || ///
lowess diff_ccap_pct eventtime if country_name=="Latvia"  & eventtime !=. & eventtime <= 15, bwidth(.3) mean lcolor(gs12) || ///
lowess diff_ccap_pct eventtime if country_name=="Luxembourg"  & eventtime !=. & eventtime <= 15, bwidth(.4) mean lcolor(gs10)|| ///
lowess diff_ccap_pct eventtime if country_name=="Austria"  & eventtime !=. & eventtime <= 15, bwidth(.5) mean  lcolor(gs4) || ///
lowess diff_ccap_pct eventtime if country_name=="Ireland"  & eventtime !=. & eventtime <= 15, bwidth(.7) mean lcolor(gs8) ///
, xline(0, lcolor(black)) yline(0, lcolor(black)) legend(off)

gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .plotregion1.plot10.style.editstyle line(width(thick)) editcopy
// plot10 width
gr_edit .plotregion1.plot13.style.editstyle line(width(thick)) editcopy
// plot13 width
gr_edit .plotregion1.plot8.style.editstyle line(width(thick)) editcopy
// plot8 width
gr_edit .plotregion1.plot14.style.editstyle line(width(thick)) editcopy
// plot14 width
gr_edit .plotregion1.plot12.style.editstyle line(width(thick)) editcopy
// plot12 width
gr_edit .plotregion1.plot9.style.editstyle line(width(thick)) editcopy
// plot9 width
gr_edit .plotregion1.plot11.style.editstyle line(width(thick)) editcopy
// plot11 width

graph export "graphics\event_ccap_pct(smooth)WorkVersion2(bold).png",width(4000) replace



	
	
**********************************************************************************************	
*Event2 (Start point: 0= last year with Commissioner; year where he leaves office)	
*Recode Denmark   //For the leave event study we need to adjust Denmark as our sample ends in 2005, but they had the Commissioner until 2009
replace eventtime2=eventtime2+3 if country_name=="Denmark" & year>=2000
		
sort year eventtime2
list year country_name eventtime2 diff_ccap_pct if eventtime2 !=.

scatter diff_ccap_pct eventtime2 if country_name=="Denmark" & year <=1999 & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs1)  || ///
scatter diff_ccap_pct eventtime2 if country_name=="Denmark" & year >=2000 & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs14)   || ///
scatter diff_ccap_pct eventtime2 if country_name=="Netherlands"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs6)  || ///
scatter diff_ccap_pct eventtime2 if country_name=="Latvia"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5 , color(gs12) || ///
scatter diff_ccap_pct eventtime2 if country_name=="Luxembourg" & eventtime2 !=. & eventtime2 <= 15  & eventtime2 >= -5, color(gs10) || ///
scatter diff_ccap_pct eventtime2 if country_name=="Austria"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs4)   || ///
scatter diff_ccap_pct eventtime2 if country_name=="Ireland"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs8)  || ///
lowess diff_ccap_pct eventtime2 if country_name=="Denmark" & year <=1999 & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, bwidth(.5) mean lcolor(gs1) || ///
lowess diff_ccap_pct eventtime2 if country_name=="Denmark" & year >=2000 & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, bwidth(.4) mean lcolor(gs14)  || ///
lowess diff_ccap_pct eventtime2 if country_name=="Netherlands"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, bwidth(.4) mean lcolor(gs6)  || ///
lowess diff_ccap_pct eventtime2 if country_name=="Latvia"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, bwidth(.3) mean lcolor(gs12) || ///
lowess diff_ccap_pct eventtime2 if country_name=="Luxembourg"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, bwidth(.4) mean lcolor(gs10)|| ///
lowess diff_ccap_pct eventtime2 if country_name=="Austria"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, bwidth(.5) mean  lcolor(gs4) || ///
lowess diff_ccap_pct eventtime2 if country_name=="Ireland"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, bwidth(.7) mean lcolor(gs8) ///
, xline(0, lcolor(black)) yline(0, lcolor(black)) legend(off)

gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .plotregion1.plot10.style.editstyle line(width(medthick)) editcopy
// plot10 width
gr_edit .plotregion1.plot13.style.editstyle line(width(medthick)) editcopy
// plot13 width
gr_edit .plotregion1.plot8.style.editstyle line(width(medthick)) editcopy
// plot8 width
gr_edit .plotregion1.plot14.style.editstyle line(width(medthick)) editcopy
// plot14 width
gr_edit .plotregion1.plot12.style.editstyle line(width(medthick)) editcopy
// plot12 width
gr_edit .plotregion1.plot9.style.editstyle line(width(medthick)) editcopy
// plot9 width
gr_edit .plotregion1.plot11.style.editstyle line(width(medthick)) editcopy
// plot11 width

graph export "graphics\event_ccap_pct2(smooth).png",width(4000) replace


sort year eventtime2
list year country_name eventtime2 diff_ccap_pct if eventtime2 !=.

scatter diff_ccap_pct eventtime2 if country_name=="Denmark" & year <=1999 & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs16)  || ///
scatter diff_ccap_pct eventtime2 if country_name=="Denmark" & year >=2000 & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs16)  || ///
scatter diff_ccap_pct eventtime2 if country_name=="Netherlands"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs16)  || ///
scatter diff_ccap_pct eventtime2 if country_name=="Latvia"  & eventtime2 !=. & eventtime2 <= 15  & eventtime2 >= -5, color(gs16) || ///
scatter diff_ccap_pct eventtime2 if country_name=="Luxembourg" & eventtime2 !=. & eventtime2 <= 15  & eventtime2 >= -5, color(gs16) || ///
scatter diff_ccap_pct eventtime2 if country_name=="Austria"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs16)   || ///
scatter diff_ccap_pct eventtime2 if country_name=="Ireland"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs16)  || ///
lowess diff_ccap_pct eventtime2 if country_name=="Denmark" & year <=1999 & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.5) mean lcolor(gs1) || ///
lowess diff_ccap_pct eventtime2 if country_name=="Denmark" & year >=2000 & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.4) mean lcolor(gs14)  || ///
lowess diff_ccap_pct eventtime2 if country_name=="Netherlands"  & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.4) mean lcolor(gs6)  || ///
lowess diff_ccap_pct eventtime2 if country_name=="Latvia"  & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.3) mean lcolor(gs12) || ///
lowess diff_ccap_pct eventtime2 if country_name=="Luxembourg"  & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.4) mean lcolor(gs10)|| ///
lowess diff_ccap_pct eventtime2 if country_name=="Austria"  & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.5) mean  lcolor(gs4) || ///
lowess diff_ccap_pct eventtime2 if country_name=="Ireland"  & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.7) mean lcolor(gs8) ///
, xline(0, lcolor(black)) yline(0, lcolor(black)) legend(off)

gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .plotregion1.plot10.style.editstyle line(width(medthick)) editcopy
// plot10 width
gr_edit .plotregion1.plot13.style.editstyle line(width(medthick)) editcopy
// plot13 width
gr_edit .plotregion1.plot8.style.editstyle line(width(medthick)) editcopy
// plot8 width
gr_edit .plotregion1.plot14.style.editstyle line(width(medthick)) editcopy
// plot14 width
gr_edit .plotregion1.plot12.style.editstyle line(width(medthick)) editcopy
// plot12 width
gr_edit .plotregion1.plot9.style.editstyle line(width(medthick)) editcopy
// plot9 width
gr_edit .plotregion1.plot11.style.editstyle line(width(medthick)) editcopy
// plot11 width

graph export "graphics\event_ccap_pct2(smooth)WorkVersion.png",width(4000) replace




sort year eventtime2
list year country_name eventtime2 diff_ccap_pct if eventtime2 !=.

scatter diff_ccap_pct eventtime2 if country_name=="Denmark" & year <=1999 & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs16)  || ///
scatter diff_ccap_pct eventtime2 if country_name=="Denmark" & year >=2000 & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs16)  || ///
scatter diff_ccap_pct eventtime2 if country_name=="Netherlands"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs16)  || ///
scatter diff_ccap_pct eventtime2 if country_name=="Latvia"  & eventtime2 !=. & eventtime2 <= 15  & eventtime2 >= -5, color(gs16) || ///
scatter diff_ccap_pct eventtime2 if country_name=="Luxembourg" & eventtime2 !=. & eventtime2 <= 15  & eventtime2 >= -5, color(gs16) || ///
scatter diff_ccap_pct eventtime2 if country_name=="Austria"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs16)   || ///
scatter diff_ccap_pct eventtime2 if country_name=="Ireland"  & eventtime2 !=. & eventtime2 <= 15 & eventtime2 >= -5, color(gs16)  || ///
lowess diff_ccap_pct eventtime2 if country_name=="Denmark" & year <=1999 & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.5) mean lcolor(gs1) || ///
lowess diff_ccap_pct eventtime2 if country_name=="Denmark" & year >=2000 & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.4) mean lcolor(gs14)  || ///
lowess diff_ccap_pct eventtime2 if country_name=="Netherlands"  & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.4) mean lcolor(gs6)  || ///
lowess diff_ccap_pct eventtime2 if country_name=="Latvia"  & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.3) mean lcolor(gs12) || ///
lowess diff_ccap_pct eventtime2 if country_name=="Luxembourg"  & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.4) mean lcolor(gs10)|| ///
lowess diff_ccap_pct eventtime2 if country_name=="Austria"  & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.5) mean  lcolor(gs4) || ///
lowess diff_ccap_pct eventtime2 if country_name=="Ireland"  & eventtime2 !=. & eventtime2 <= 15& eventtime2 >= -5, bwidth(.7) mean lcolor(gs8) ///
, xline(0, lcolor(black)) yline(0, lcolor(black)) legend(off)

gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
// Graph color
gr_edit .plotregion1.plot10.style.editstyle line(width(thick)) editcopy
// plot10 width
gr_edit .plotregion1.plot13.style.editstyle line(width(thick)) editcopy
// plot13 width
gr_edit .plotregion1.plot8.style.editstyle line(width(thick)) editcopy
// plot8 width
gr_edit .plotregion1.plot14.style.editstyle line(width(thick)) editcopy
// plot14 width
gr_edit .plotregion1.plot12.style.editstyle line(width(thick)) editcopy
// plot12 width
gr_edit .plotregion1.plot9.style.editstyle line(width(thick)) editcopy
// plot9 width
gr_edit .plotregion1.plot11.style.editstyle line(width(thick)) editcopy
// plot11 width

graph export "graphics\event_ccap_pct2(smooth)WorkVersion2(bold).png",width(4000) replace



	
	
	
**********************************************************************************************	

exit
**********************************************************************************************	
		
	
