*******************************************************************************
*******************************************************************************
/*
***   File name   : master_Gehring_Schneiderdo                              ***
***   Last Update : December 17, 2016                                       ***
***   Author      : Kai Gehring, University of Zurich                       ***
***                 Stephan A. Schneider, Heidelberg University             ***
***                 ...                                                     ***
***   Requires    : ---extended_eupower.dta, EUcouncilpres.xlsx,            ***
		EUcomm_presidents.xlsx, eba_country_file.dta,wstar_file.dta         ***
***   Purpose     : Creates regressions, presented in the Seminar Paper     ***

You have to run the whole file including all locals and globals to replicate the results. The beginning of the code automatically loads external packages that are not
native to Stata. All three sub-do-files must remain in the same folder. Please insert the folder "Stata" which contains the extracted data files as the 
relative path (see example below). he code will automatically create sub-folders for tables and graphics, in which the results will be stored.
Tables can be found under "\Tables" and figures under "\Figures".

Please also note that the user-writen xtivreg2 and ivreg2 command repeatedly will issue a warning:
"Warning: estimated covariance matrix of moment conditions not of full rank. Overidentification statistic not reported, and standard errors and
model tests should be interpreted with caution."
This means only that the overall F-statistic cannot be interpreted directly, the significance tests of individual coefficients and their combination
which we use are not affected.
*******************************************************************************
*******************************************************************************
*/

version 12.1
drop _all
clear matrix
clear mata
set matsize 4000
*********************************Set*file*path*********************************
*Example
*local DIR ="C:\Users\XXX...\EU Commissioners\Stata"
*Your path
local DIR ="..."		
cd "`DIR'" 
*******************************************************************************
set more off, perm

/*Choose the nummber of repetitions for the bootstap simulations in the table (bots) and for the figures (botF).
The default is 25,000, which takes very long. All other results in the except the simulations can be replicated
putting a small number like here which drastically reduces the time to run */
global bots 25000
global botF 10000



 
cap noisily net install regsave,  from(http://fmwww.bc.edu/RePEc/bocode/r/)
capture net install psacalc, from(http://fmwww.bc.edu/RePEc/bocode/p)			/* checks whether spmon is installed		*/
capture net install moremata, from(http://ideas.repec.org/c/boc/bocode/s455001.html)
capture net install use13,from(http://fmwww.bc.edu/RePEc/bocode/u/)
capture net install ivreg2 from (http://fmwww.bc.edu/RePEc/bocode/i)
capture net install xtivreg2 from (http://fmwww.bc.edu/RePEc/bocode/x)
capture net install wbopendata.pkg from(http://fmwww.bc.edu/RePEc/bocode/w/)
capture net install carryforward.pkg from (http://fmwww.bc.edu/RePEc/bocode/c/)

*** Create folders "data processed"(where transformed data are stored) and "tables" (where tables are stored)
program define confirmdir, rclass
		local cwd `"`c(pwd)'"'
		quietly capture cd `"`1'"'
		local confirmdir=_rc 
		quietly cd `"`cwd'"'
		return local confirmdir `"`confirmdir'"'
	end 
		confirmdir `"data processed"'	  	/* does folder "data processed" exist? */
			if `r(confirmdir)'!=0  {  	/* folder does not yet exist */
				mkdir "data processed"  	/* makes the folder  */
							  } 
			  else {
				di "folder data processed already exists"
				}
		confirmdir `"Tables"'		  /* does folder "Tables" exist? */
			if `r(confirmdir)'!=0  {  /* folder does not yet exist */
				mkdir "Tables"  /* makes the folder  */
							  } 
			  else {
				di "folder tables already exists"
				}
		confirmdir `"graphics"'		  /* does folder "graphics" exist? */
			if `r(confirmdir)'!=0  {  /* folder does not yet exist */
				mkdir "graphics"  /* makes the folder  */
							  } 
			  else {
				di "folder graphics already exists"
				}
	program drop confirmdir

do "..\Do-Files\WildClusterBootstrap.do"

*do "..\Do-Files\powerintheeu_public(part1).do" //Comment in for creation of the data set. This could lead to slight deviations due to the usage of the wbopendata command, as the World Bank sometimes revises data.

do "..\Do-Files\powerintheeu_public(part2).do"


